@@ -7,11 +7,11 @@ from windyquery import DB
 @pytest.fixture(scope="module")
 def config():
     class Config:
-        DB_HOST = "192.168.99.100"
+        DB_HOST = "localhost"
         DB_PORT = "5432"
-        DB_TEST = "windyquery-test"
-        DB_USER = "windyquery-test"
-        DB_PASS = "windyquery-test"
+        DB_TEST = "xli"
+        DB_USER = "xli"
+        DB_PASS = "xliadmin"
     yield Config
 
 
